# sem_search
 
This is designed to allow for rapid semantic search.

It draws inspiration and code from Mathew Alexander's implementation [here] (https://towardsdatascience.com/billion-scale-semantic-similarity-search-with-faiss-sbert-c845614962e2):